@@ -3,10 +3,9 @@ package GeoIP2::Database::Reader;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use Data::Validate::IP 0.24
     qw( is_ipv4 is_ipv6 is_private_ipv4 is_private_ipv6 );
@@ -23,6 +22,8 @@ use GeoIP2::Model::ISP;
 use GeoIP2::Types qw( Str );
 use MaxMind::DB::Reader 1.000000;
 
+use namespace::clean -except => 'meta';
+
 with 'GeoIP2::Role::HasLocales';
 
 has file => (
@@ -191,7 +192,7 @@ GeoIP2::Database::Reader - Perl API for GeoIP2 databases
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
