@@ -3,10 +3,11 @@ package GeoIP2::Error::HTTP;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
+
+use namespace::clean -except => 'meta';
 
 with 'GeoIP2::Role::Error::HTTP';
 
@@ -28,7 +29,7 @@ GeoIP2::Error::HTTP - An HTTP transport error
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
