@@ -3,13 +3,14 @@ package GeoIP2::Error::IPAddressNotFound;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( Str );
 
+use namespace::clean -except => 'meta';
+
 extends 'Throwable::Error';
 
 has ip_address => (
@@ -34,7 +35,7 @@ GeoIP2::Error::IPAddressNotFound - An exception thrown when an IP address is not
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
