@@ -3,10 +3,11 @@ package GeoIP2::Error::Type;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
+
+use namespace::clean -except => 'meta';
 
 extends 'Throwable::Error';
 
@@ -38,7 +39,7 @@ GeoIP2::Error::Type - A type validation error.
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
