@@ -3,13 +3,14 @@ package GeoIP2::Error::WebService;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( Str );
 
+use namespace::clean -except => 'meta';
+
 with 'GeoIP2::Role::Error::HTTP';
 
 extends 'Throwable::Error';
@@ -36,7 +37,7 @@ GeoIP2::Error::WebService - An explicit error from the GeoIP2 web service
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
