@@ -3,14 +3,15 @@ package GeoIP2::Model::Country;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( HashRef object_isa_type );
 use Sub::Quote qw( quote_sub );
 
+use namespace::clean -except => 'meta';
+
 with 'GeoIP2::Role::Model::Location';
 
 ## no critic (ProhibitUnusedPrivateSubroutines)
@@ -36,7 +37,7 @@ GeoIP2::Model::Country - Model class for the GeoIP2 Precision: Country and GeoIP
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
