@@ -3,13 +3,14 @@ package GeoIP2::Model::ISP;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( IPAddress NonNegativeInt Str );
 
+use namespace::clean -except => 'meta';
+
 with 'GeoIP2::Role::Model::Flat', 'GeoIP2::Role::HasIPAddress';
 
 has autonomous_system_number => (
@@ -52,7 +53,7 @@ GeoIP2::Model::ISP - Model class for the GeoIP2 ISP database
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
