@@ -3,13 +3,14 @@ package GeoIP2::Record::Continent;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( PositiveInt Str );
 
+use namespace::clean -except => 'meta';
+
 with 'GeoIP2::Role::Record::HasNames';
 
 has code => (
@@ -40,7 +41,7 @@ GeoIP2::Record::Continent - Contains data for the continent record associated wi
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
