@@ -3,13 +3,14 @@ package GeoIP2::Record::Location;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( NonNegativeInt Num PositiveInt Str );
 
+use namespace::clean -except => 'meta';
+
 has accuracy_radius => (
     is        => 'ro',
     isa       => PositiveInt,
@@ -68,7 +69,7 @@ GeoIP2::Record::Location - Contains data for the location record associated with
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
