@@ -3,13 +3,14 @@ package GeoIP2::Record::MaxMind;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( NonNegativeInt );
 
+use namespace::clean -except => 'meta';
+
 has queries_remaining => (
     is  => 'ro',
     isa => NonNegativeInt,
@@ -31,7 +32,7 @@ GeoIP2::Record::MaxMind - Contains data for the maxmind record returned from a w
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
