@@ -3,13 +3,14 @@ package GeoIP2::Record::Postal;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( NonNegativeInt Str );
 
+use namespace::clean -except => 'meta';
+
 has code => (
     is        => 'ro',
     isa       => Str,
@@ -38,7 +39,7 @@ GeoIP2::Record::Postal - Contains data for the postal code record associated wit
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
