@@ -3,13 +3,14 @@ package GeoIP2::Record::RepresentedCountry;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( Str );
 
+use namespace::clean -except => 'meta';
+
 with 'GeoIP2::Role::Record::Country';
 
 has type => (
@@ -34,7 +35,7 @@ GeoIP2::Record::RepresentedCountry - Contains data for the represented country r
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
