@@ -3,13 +3,14 @@ package GeoIP2::Record::Subdivision;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( NonNegativeInt PositiveInt Str );
 
+use namespace::clean -except => 'meta';
+
 with 'GeoIP2::Role::Record::HasNames';
 
 has confidence => (
@@ -46,7 +47,7 @@ GeoIP2::Record::Subdivision - Contains data for the subdivision record associate
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
