@@ -3,13 +3,14 @@ package GeoIP2::Role::Error::HTTP;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo::Role;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( HTTPStatus Str URIObject );
 
+use namespace::clean;
+
 has http_status => (
     is       => 'ro',
     isa      => HTTPStatus,
