@@ -3,13 +3,14 @@ package GeoIP2::Role::Model;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo::Role;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( HashRef );
 
+use namespace::clean;
+
 has raw => (
     is       => 'ro',
     isa      => HashRef,
