@@ -3,10 +3,11 @@ package GeoIP2::Role::Model::Flat;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo::Role;
-use namespace::autoclean;
+
+use namespace::clean;
 
 around BUILDARGS => sub {
     my $orig = shift;
