@@ -3,10 +3,9 @@ package GeoIP2::Role::Model::Location;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo::Role;
-use namespace::autoclean;
 
 use B;
 use GeoIP2::Record::City;
@@ -20,6 +19,8 @@ use GeoIP2::Record::Traits;
 use GeoIP2::Types qw( ArrayRef HashRef );
 use Sub::Quote qw( quote_sub );
 
+use namespace::clean;
+
 with 'GeoIP2::Role::Model', 'GeoIP2::Role::HasLocales';
 
 ## no critic (ProhibitUnusedPrivateSubroutines)
