@@ -3,13 +3,14 @@ package GeoIP2::Role::Record::Country;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo::Role;
-use namespace::autoclean;
 
 use GeoIP2::Types qw( NonNegativeInt PositiveInt Str );
 
+use namespace::clean;
+
 with 'GeoIP2::Role::Record::HasNames';
 
 has iso_code => (
