@@ -5,10 +5,9 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003004';
 
 use Moo;
-use namespace::autoclean;
 
 use Data::Validate::IP 0.19 qw( is_public_ipv4 is_public_ipv6 );
 use GeoIP2::Error::Generic;
@@ -32,6 +31,8 @@ use Sub::Quote qw( quote_sub );
 use Try::Tiny;
 use URI;
 
+use namespace::clean -except => 'meta';
+
 with 'GeoIP2::Role::HasLocales';
 
 has user_id => (
@@ -317,7 +318,7 @@ GeoIP2::WebService::Client - Perl API for the GeoIP2 Precision web services
 
 =head1 VERSION
 
-version 2.003003
+version 2.003004
 
 =head1 SYNOPSIS
 
